%bcond_without static
%bcond_without check
%global mpi_list %{?mpi_list} mpich openmpi

Name:           yaxt
Version:        0.5.1
Release:        1%{?dist}
Summary:        Yet Another eXchange Tool

License:        BSD
URL:            https://www.dkrz.de/redmine/projects/%{name}
Source0:        https://www.dkrz.de/redmine/attachments/download/474/%{name}-%{version}.tar.xz

BuildRequires:  doxygen
BuildRequires:  gcc-gfortran
BuildRequires:  graphviz
BuildRequires:  perl-Data-Dumper
BuildRequires:  perl-File-Temp
BuildRequires:  perl-Getopt-Long
BuildRequires:  perl-Storable

%description
YAXT is a C library built on MPI for the redistribution of data between two sets
of processes. It is inspired by the Fortran prototype Unitrans by Mathias Pütz
in ScalES-project.

The %{name} package contains documentation for %{name}.

%package        mpich
Summary:        MPICH MPI libraries for %{name}
BuildRequires:  mpich-devel

%description    mpich
The %{name}-mpich package contains MPICH MPI libraries for %{name}.

%package        mpich-devel
Summary:        Development files for %{name}-mpich
Requires:       %{name}-mpich%{?_isa} = %{version}-%{release}

%description    mpich-devel
The %{name}-mpich-devel package contains libraries and header files for
developing applications that use %{name}-mpich.

%if %{with static}
%package        mpich-static
Summary:        Static libraries for %{name}-mpich
Requires:       %{name}-mpich-devel%{?_isa} = %{version}-%{release}

%description    mpich-static
The %{name}-mpich-static package contains static libraries for developing
applications that use %{name}-mpich.
%endif

%package        openmpi
Summary:        OpenMPI MPI libraries for %{name}
BuildRequires:  openmpi-devel

%description    openmpi
The %{name}-openmpi package contains OpenMPI MPI libraries for %{name}.

%package        openmpi-devel
Summary:        Development files for %{name}-openmpi
Requires:       %{name}-openmpi%{?_isa} = %{version}-%{release}

%description    openmpi-devel
The %{name}-openmpi-devel package contains libraries and header files for
developing applications that use %{name}-openmpi.

%if %{with static}
%package        openmpi-static
Summary:        Static libraries for %{name}-openmpi
Requires:       %{name}-openmpi-devel%{?_isa} = %{version}-%{release}

%description    openmpi-static
The %{name}-openmpi-static package contains static libraries for developing
applications that use %{name}-openmpi.
%endif

%package        doc
Summary:        Documentation files for %{name}

%description    doc
The %{name}-doc package contains documentation files for developing applications
that use %{name}.

%prep
%autosetup

%build
# Common configure options
# Dependency tracking necessary for f90 module dependencies
%global configure_opts \\\
  --enable-dependency-tracking \\\
  %{!?with_static:--disable-static}
# MPI builds
export CC=mpicc
export FC=mpifort
for mpi in %{mpi_list}; do
  mkdir ${mpi}
  pushd ${mpi}
  module load mpi/${mpi}-%{_arch}
  ln -s ../configure .
  %configure %{configure_opts} \
    FCFLAGS="$FCFLAGS -I${MPI_FORTRAN_MOD_DIR}" \
    MPI_LAUNCH=mpirun \
    --libdir=%{_libdir}/${mpi}/lib \
    --bindir=%{_libdir}/${mpi}/bin \
    --sbindir=%{_libdir}/${mpi}/sbin \
    --includedir=%{_includedir}/${mpi}-%{_arch} \
    --datarootdir=%{_libdir}/${mpi}/share \
    --mandir=%{_libdir}/${mpi}/share/man
  %make_build
  module purge
  popd
done

doxygen -u doc/Doxyfile.in
doxygen doc/Doxyfile.in

%install
rm -rf $RPM_BUILD_ROOT
for mpi in %{mpi_list}; do
  pushd ${mpi}
  module load mpi/${mpi}-%{_arch}
  %make_install
  rm -f ${RPM_BUILD_ROOT}/%{_libdir}/${mpi}/lib/*.la
  module purge
  popd
done

%check
%if %{with check}
for mpi in %{mpi_list}; do
  module load mpi/${mpi}-%{_arch}
  %{__make} -C ${mpi} check
  module purge
done
%endif

%files
%doc README

%files          mpich
%{_libdir}/mpich/lib/*.so.*

%files          mpich-devel
%{_includedir}/mpich-%{_arch}/*
%{_libdir}/mpich/lib/*.so
%{_libdir}/mpich/lib/pkgconfig/%{name}.pc

%if %{with static}
%files          mpich-static
%{_libdir}/mpich/lib/*.a
%endif

%files          openmpi
%{_libdir}/openmpi/lib/*.so.*

%files          openmpi-devel
%{_includedir}/openmpi-%{_arch}/*
%{_libdir}/openmpi/lib/*.so
%{_libdir}/openmpi/lib/pkgconfig/%{name}.pc

%if %{with static}
%files          openmpi-static
%{_libdir}/openmpi/lib/*.a
%endif

%files          doc
%doc doc/cfortran.*
%doc doc/html
%doc doc/styleguide.txt
%doc examples/*.c
%doc examples/*.h
%doc examples/*.f90

%changelog
* Sat Apr  8 2017 Matthew Krupcale <mkrupcale@matthewkrupcale.com> - 0.5.1-1
- Initial packaging.
